@@ -1,12 +1,11 @@
-from openskill.rate import ordinal
 from openskill.rate import (
-    rate,
     Rating,
     create_rating,
-    team_rating,
-    predict_win,
+    ordinal,
     predict_draw,
+    predict_win,
+    rate,
+    team_rating,
 )
 
-
-__version__ = "2.5.1"
+__version__ = "3.0.0"
